summaryrefslogtreecommitdiff
path: root/framework
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2014-11-10 15:05:25 +0100
committerNoel Grandin <noelgrandin@gmail.com>2014-11-12 11:04:11 +0000
commitda40cac540e7d735edbe9069b3c8ec6af4530208 (patch)
treef2abda7281129e13f588c77b18780a7090c8405f /framework
parentbb437029c1e5331bcc3f8fb2fc87837142a52f33 (diff)
Fix common typos. No automatic tools. Handmade…
Change-Id: I1ab4e23b0539f8d39974787f226e57a21f96e959 Reviewed-on: https://gerrit.libreoffice.org/12164 Reviewed-by: Noel Grandin <noelgrandin@gmail.com> Tested-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'framework')
-rw-r--r--framework/inc/dispatch/closedispatcher.hxx6
-rw-r--r--framework/inc/dispatch/oxt_handler.hxx2
-rw-r--r--framework/inc/helper/vclstatusindicator.hxx2
-rw-r--r--framework/inc/jobs/job.hxx2
-rw-r--r--framework/inc/services/desktop.hxx4
-rw-r--r--framework/inc/threadhelp/gate.hxx2
-rw-r--r--framework/inc/threadhelp/transactionguard.hxx2
-rw-r--r--framework/qa/complex/framework/autosave/AutoSave.java2
-rw-r--r--framework/qa/complex/framework/recovery/RecoveryTest.java2
-rw-r--r--framework/source/accelerators/keymapping.cxx2
-rw-r--r--framework/source/classes/menumanager.cxx2
-rw-r--r--framework/source/dispatch/dispatchprovider.cxx2
-rw-r--r--framework/source/fwe/helper/undomanagerhelper.cxx2
-rw-r--r--framework/source/helper/statusindicatorfactory.cxx4
-rw-r--r--framework/source/inc/loadenv/loadenv.hxx22
-rw-r--r--framework/source/inc/loadenv/targethelper.hxx2
-rw-r--r--framework/source/inc/pattern/window.hxx2
-rw-r--r--framework/source/jobs/job.cxx6
-rw-r--r--framework/source/jobs/jobexecutor.cxx2
-rw-r--r--framework/source/services/autorecovery.cxx46
-rw-r--r--framework/source/services/desktop.cxx10
-rw-r--r--framework/source/services/frame.cxx30
-rw-r--r--framework/source/services/modulemanager.cxx2
-rw-r--r--framework/source/services/pathsettings.cxx20
-rw-r--r--framework/source/services/substitutepathvars.cxx6
-rw-r--r--framework/source/uiconfiguration/uicategorydescription.cxx2
26 files changed, 93 insertions, 93 deletions
diff --git a/framework/inc/dispatch/closedispatcher.hxx b/framework/inc/dispatch/closedispatcher.hxx
index dfbf6bf6eca2..192e2e8ffd1e 100644
--- a/framework/inc/dispatch/closedispatcher.hxx
+++ b/framework/inc/dispatch/closedispatcher.hxx
@@ -198,8 +198,8 @@ class CloseDispatcher : public ::cppu::WeakImplHelper2<
before (e.g. by calling implts_closeView()!
Otherwise e.g. the XController->suspend()
- call isnt made and no UI warn the user about
- loosing document changes. Because the
+ call is not made and no UI warn the user about
+ losing document changes. Because the
frame is closed ....
@return [bool]
@@ -218,7 +218,7 @@ class CloseDispatcher : public ::cppu::WeakImplHelper2<
/** @short calls XDesktop->terminate().
@descr No office code has to be called
- afterwards! Because the process is dieing ...
+ afterwards! Because the process is dying...
The only exception is a might be registered
listener at this instance here.
Because he should know, that such things will happen :-)
diff --git a/framework/inc/dispatch/oxt_handler.hxx b/framework/inc/dispatch/oxt_handler.hxx
index b32a53e21c68..999c2ddb06c3 100644
--- a/framework/inc/dispatch/oxt_handler.hxx
+++ b/framework/inc/dispatch/oxt_handler.hxx
@@ -102,7 +102,7 @@ class Oxt_Handler : public ::cppu::WeakImplHelper3<
osl::Mutex m_mutex;
css::uno::Reference< css::lang::XMultiServiceFactory > m_xFactory; /// global uno service factory to create new services
- css::uno::Reference< css::uno::XInterface > m_xSelfHold; /// we must protect us against dieing during async(!) dispatch() call!
+ css::uno::Reference< css::uno::XInterface > m_xSelfHold; /// we must protect us against dying during async(!) dispatch() call!
css::uno::Reference< css::frame::XDispatchResultListener > m_xListener;
}; // class Oxt_Handler
diff --git a/framework/inc/helper/vclstatusindicator.hxx b/framework/inc/helper/vclstatusindicator.hxx
index 634c66a5b1f5..4a68b79d8271 100644
--- a/framework/inc/helper/vclstatusindicator.hxx
+++ b/framework/inc/helper/vclstatusindicator.hxx
@@ -48,7 +48,7 @@ class VCLStatusIndicator : public ::cppu::WeakImplHelper1< css::task::XStatusIn
/** shows the progress.
- @attention This member isnt synchronized using our own mutex!
+ @attention This member is not synchronized using our own mutex!
Its guarded by the solarmutex only. Otherwise
we have to lock two of them, which can force a deadlock ...
*/
diff --git a/framework/inc/jobs/job.hxx b/framework/inc/jobs/job.hxx
index 6b5ff39c9b1d..7f01fec6a0b5 100644
--- a/framework/inc/jobs/job.hxx
+++ b/framework/inc/jobs/job.hxx
@@ -158,7 +158,7 @@ class Job : public ::cppu::WeakImplHelper3<
indicates in which state the internal job currently exist.
We can use this information to throw any suitable veto exception
- to prevent the environment against dieing or suppress superflous dispose()
+ to prevent the environment against dying or suppress superflous dispose()
calls at the job.
*/
ERunState m_eRunState;
diff --git a/framework/inc/services/desktop.hxx b/framework/inc/services/desktop.hxx
index 19a6df5800f9..40d349ceefab 100644
--- a/framework/inc/services/desktop.hxx
+++ b/framework/inc/services/desktop.hxx
@@ -385,7 +385,7 @@ class Desktop : private cppu::BaseMutex,
bool impl_closeFrames(bool bAllowUI);
// debug methods
- // (should be private everytime!)
+ // (should be private every time!)
private:
@@ -396,7 +396,7 @@ class Desktop : private cppu::BaseMutex,
/// see dispose() for further information!
// variables
- // (should be private everytime!)
+ // (should be private every time!)
private:
diff --git a/framework/inc/threadhelp/gate.hxx b/framework/inc/threadhelp/gate.hxx
index 04c6ce72745d..422d629a2df8 100644
--- a/framework/inc/threadhelp/gate.hxx
+++ b/framework/inc/threadhelp/gate.hxx
@@ -35,7 +35,7 @@ namespace framework{
As a special feature you can open the gate a little bit by sing openGap().
Then all currently waiting threads are running immediately - but new ones are blocked!
- @attention To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+ @attention To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
@implements IGate
@base IGate
diff --git a/framework/inc/threadhelp/transactionguard.hxx b/framework/inc/threadhelp/transactionguard.hxx
index 81930e2683c7..83cc30150193 100644
--- a/framework/inc/threadhelp/transactionguard.hxx
+++ b/framework/inc/threadhelp/transactionguard.hxx
@@ -35,7 +35,7 @@ namespace framework{
It's possible too, to enable automatically throwing of some exceptions for illegal
transaction requests ... e.g. interface call for already disposed objects.
- @attention To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+ @attention To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
@devstatus draft
*//*-*************************************************************************************************************/
class TransactionGuard : private boost::noncopyable
diff --git a/framework/qa/complex/framework/autosave/AutoSave.java b/framework/qa/complex/framework/autosave/AutoSave.java
index dd50de5741d3..33effb441304 100644
--- a/framework/qa/complex/framework/autosave/AutoSave.java
+++ b/framework/qa/complex/framework/autosave/AutoSave.java
@@ -324,7 +324,7 @@ public class AutoSave
{
m_aLog.log(Protocol.TYPE_WARNING , "got CloseVetoException on calling doc.close()." );
m_aLog.log(Protocol.TYPE_WARNING_INFO, "Please check the reason for that more in detail." );
- m_aLog.log(Protocol.TYPE_WARNING_INFO, "A message like \"Cant close while saving.\" was intended and doesn't show an error!");
+ m_aLog.log(Protocol.TYPE_WARNING_INFO, "A message like \"Can not close while saving.\" was intended and doesn't show an error!");
m_aLog.log(Protocol.TYPE_WARNING_INFO, exVeto.getMessage());
}
diff --git a/framework/qa/complex/framework/recovery/RecoveryTest.java b/framework/qa/complex/framework/recovery/RecoveryTest.java
index 463f748ba206..cfb767790b6d 100644
--- a/framework/qa/complex/framework/recovery/RecoveryTest.java
+++ b/framework/qa/complex/framework/recovery/RecoveryTest.java
@@ -521,7 +521,7 @@ public class RecoveryTest extends ComplexTestCase {
Rectangle posSize = new Rectangle();
Random rand = new Random();
- // Random integers that range from from 0 to n
+ // Random integers that range from 0 to n
posSize.X = rand.nextInt(windowMaxPosition.x + 1);
posSize.Y = rand.nextInt(windowMaxPosition.y + 1);
diff --git a/framework/source/accelerators/keymapping.cxx b/framework/source/accelerators/keymapping.cxx
index 188609b8eb87..03d0189a34e9 100644
--- a/framework/source/accelerators/keymapping.cxx
+++ b/framework/source/accelerators/keymapping.cxx
@@ -170,7 +170,7 @@ sal_uInt16 KeyMapping::mapIdentifierToCode(const OUString& sIdentifier)
sal_uInt16 nCode = 0;
if (!KeyMapping::impl_st_interpretIdentifierAsPureKeyCode(sIdentifier, nCode))
throw css::lang::IllegalArgumentException(
- "Cant map given identifier to a valid key code value.",
+ "Can not map given identifier to a valid key code value.",
css::uno::Reference< css::uno::XInterface >(),
0);
diff --git a/framework/source/classes/menumanager.cxx b/framework/source/classes/menumanager.cxx
index 519c795fa3a7..0abb09306d2a 100644
--- a/framework/source/classes/menumanager.cxx
+++ b/framework/source/classes/menumanager.cxx
@@ -732,7 +732,7 @@ IMPL_LINK( MenuManager, Activate, Menu *, pMenu )
OUString aCommand( m_aMenuItemCommand );
if (m_aMenuItemCommand.matchIgnoreAsciiCase(UNO_COMMAND))
{
- // Remove protocol part from command so we can use an easier comparision method
+ // Remove protocol part from command so we can use an easier comparison method
aCommand = aCommand.copy(RTL_CONSTASCII_LENGTH(UNO_COMMAND));
}
diff --git a/framework/source/dispatch/dispatchprovider.cxx b/framework/source/dispatch/dispatchprovider.cxx
index c1b8da31ad9b..c45661996016 100644
--- a/framework/source/dispatch/dispatchprovider.cxx
+++ b/framework/source/dispatch/dispatchprovider.cxx
@@ -281,7 +281,7 @@ css::uno::Reference< css::frame::XDispatch > DispatchProvider::implts_queryFrame
// I.IV) "_beamer"
// Special sub frame of a top frame only. Search or create it. ... OK it's currently a little bit HACKI.
- // Only the sfx (means the controller) can create it it.
+ // Only the sfx (means the controller) can create it.
else if (sTargetName==SPECIALTARGET_BEAMER)
{
diff --git a/framework/source/fwe/helper/undomanagerhelper.cxx b/framework/source/fwe/helper/undomanagerhelper.cxx
index 1d4f13aabfb6..8244b1f57d59 100644
--- a/framework/source/fwe/helper/undomanagerhelper.cxx
+++ b/framework/source/fwe/helper/undomanagerhelper.cxx
@@ -167,7 +167,7 @@ namespace framework
void cancel( const Reference< XInterface >& i_context )
{
m_caughtException <<= RuntimeException(
- OUString( "Concurrency error: an ealier operation on the stack failed." ),
+ OUString( "Concurrency error: an earlier operation on the stack failed." ),
i_context
);
m_finishCondition.set();
diff --git a/framework/source/helper/statusindicatorfactory.cxx b/framework/source/helper/statusindicatorfactory.cxx
index b0b5f3d9c060..5067a66217de 100644
--- a/framework/source/helper/statusindicatorfactory.cxx
+++ b/framework/source/helper/statusindicatorfactory.cxx
@@ -340,8 +340,8 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
}
}
- // Ok the window should be made visible ... because it isnt currently visible.
- // BUT ..!
+ // Ok the window should be made visible... because it is not currently visible.
+ // BUT..!
// We need a Hack for our applications: They get her progress from the frame directly
// on saving documents. Because there is no progress set on the MediaDescriptor.
// But that's wrong. In case the document was opened hidden, they should not use any progress .-(
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index 95367eb745b1..ae598dfbc6e1 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -259,7 +259,7 @@ public:
This value is set to a default value "UNKNWON_CONTENT", which force
an internal check, if this content is loadable or not.
But may this check was already made by the caller of this method and
- passing this information to this LoadEnv instance can supress this
+ passing this information to this LoadEnv instance can suppress this
might expensive check.
That can be useful in case this information is needed outside too,
to decide if its necessary to create some resources for this load
@@ -433,7 +433,7 @@ private:
for the detected content type (must be done before by calling
impl_detectTypeAndFilter()). Because such handler does not depend
from a real target frame, location of such frame will be
- supressed here.
+ suppressed here.
In case handle failed all new created resources will be
removed before a suitable exception is thrown.
(Excepting a RuntimeException occurrence!)
@@ -524,29 +524,29 @@ private:
css::uno::Reference< css::frame::XFrame > impl_searchRecycleTarget()
throw(LoadEnvException, css::uno::RuntimeException, std::exception);
- /** @short because showing of a frame is needed more than once ...
+ /** @short because showing of a frame is needed more than once...
it's implemented as an separate method .-)
- @descr Note: Showing of a frame is bound to a special feature ...
+ @descr Note: Showing of a frame is bound to a special feature...
a) If we recycle any existing frame, we must bring it to front.
- Showing of such frame isnt needed really .. because we recycle
+ Showing of such frame is not needed really.. because we recycle
visible frames only!
b) If the document was already shown (e.g. by our progress implementation)
- we do nothing here. The reason behind: The document was already shown ..
- and it was already make a top window ...
+ we do nothing here. The reason behind: The document was already shown...
+ and it was already make a top window...
If the user activated another frame inbetween (because loading needed some time)
it's not allowed to disturb the user again. Then the frame must resists in the background.
- c) If the frame was not shown before ... but loading of a visible document into this frame
- was finished ... we need both actions: setVisible() and toFront().
+ c) If the frame was not shown before... but loading of a visible document into this frame
+ was finished... we need both actions: setVisible() and toFront().
@param xWindow
points to the container window of a frame.
@param bForceToFront
- if it's set to sal_False ... showing of the window is done more intelligent.
+ if it's set to sal_False... showing of the window is done more intelligent.
setVisible() is called only if the window was not shown before.
This mode is needed by b) and c)
- If it's set to sal_True ... both actions has to be done: setVisible(), toFront()!
+ If it's set to sal_True... both actions has to be done: setVisible(), toFront()!
This mode is needed by a)
*/
void impl_makeFrameWindowVisible(const css::uno::Reference< css::awt::XWindow >& xWindow ,
diff --git a/framework/source/inc/loadenv/targethelper.hxx b/framework/source/inc/loadenv/targethelper.hxx
index d0c960df754d..f982d02df824 100644
--- a/framework/source/inc/loadenv/targethelper.hxx
+++ b/framework/source/inc/loadenv/targethelper.hxx
@@ -91,7 +91,7 @@ class TargetHelper
and the value must not a well known special target.
@param sName
- the new frame name, which sould be checked.
+ the new frame name, which should be checked.
*/
static bool isValidNameForFrame(const OUString& sName);
};
diff --git a/framework/source/inc/pattern/window.hxx b/framework/source/inc/pattern/window.hxx
index 7ff8d45dfaa7..8779aa28476c 100644
--- a/framework/source/inc/pattern/window.hxx
+++ b/framework/source/inc/pattern/window.hxx
@@ -103,7 +103,7 @@ static bool isTopWindow(const css::uno::Reference< css::awt::XWindow >& xWindow)
{
// Note: Toolkit interface XTopWindow sometimes is used by real VCL-child-windows also .-)
// Be sure that these window is really a "top system window".
- // Attention ! Checking Window->GetParent() isnt the right approach here.
+ // Attention ! Checking Window->GetParent() is not the right approach here.
// Because sometimes VCL create "implicit border windows" as parents even we created
// a simple XWindow using the toolkit only .-(
SolarMutexGuard aSolarGuard;
diff --git a/framework/source/jobs/jobexecutor.cxx b/framework/source/jobs/jobexecutor.cxx
index e4dfbb06138c..8f6243f6c396 100644
--- a/framework/source/jobs/jobexecutor.cxx
+++ b/framework/source/jobs/jobexecutor.cxx
@@ -60,7 +60,7 @@ typedef cppu::WeakComponentImplHelper4<
@short implements a job executor, which can be triggered from any code
@descr It uses the given trigger event to locate any registered job service
inside the configuration and execute it. Of course it controls the
- liftime of such jobs too.
+ lifetime of such jobs too.
*/
class JobExecutor : private cppu::BaseMutex, public Base
{
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index bde7706c825f..6f8b013e2fc6 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -570,7 +570,7 @@ css::uno::Reference< css::lang::XComponent > SAL_CALL Desktop::loadComponentFrom
/*-************************************************************************************************************
@interface XTasksSupplier
@short get access to create enumerations of our taskchildren
- @descr Direct children of desktop are tasks everytime.
+ @descr Direct children of desktop are tasks every time.
Call these method to could create enumerations of it.
But; Don't forget - you will be the owner of returned object and must release it!
@@ -948,7 +948,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Desktop::findFrame( const OUS
// But we ust break further searches if target was already found.
// Order of using flags is fix: SELF - CHILDREN - SIBLINGS - PARENT
// TASK and CREATE are handled special.
- // But note: Such flags are not valid for the desktop - especialy SIBLINGS or PARENT.
+ // But note: Such flags are not valid for the desktop - especially SIBLINGS or PARENT.
// II.I) SELF
// Check for right name. If it's the searched one return ourself - otherwise
@@ -965,7 +965,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Desktop::findFrame( const OUS
// II.II) TASKS
// This is a special flag. Normally it regulate search inside tasks and forbid access to parent trees.
// But the desktop exists outside such task trees. They are our sub trees. So the desktop implement
- // a special feature: We use it to start search on our direct children only. That means we supress
+ // a special feature: We use it to start search on our direct children only. That means we suppress
// search on ALL child frames. May that can be useful to get access on opened document tasks
// only without filter out all non really required sub frames ...
// Used helper method on our container doesn't create any frame - it's a search only.
@@ -1083,7 +1083,7 @@ void SAL_CALL Desktop::disposing()
@interface XComponent
@short add/remove listener for dispose events
@descr Add an event listener to this object, if you wish to get information
- about our dieing!
+ about our dying!
You must releas ethis listener reference during your own disposing() method.
@attention Our container is threadsafe himeslf. So we don't need any lock here.
@@ -1187,7 +1187,7 @@ void SAL_CALL Desktop::handle( const css::uno::Reference< css::task::XInteractio
TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
// Don't check incoming request!
- // If somewhere starts interaction without right parameter - he maked something wrong.
+ // If somewhere starts interaction without right parameter - he made something wrong.
// loadComponentFromURL() waits for thjese event - otherwise it yield for ever!
// get packed request and work on it first
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 1ac2e80ad111..74a146a181ab 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -547,10 +547,10 @@ void Frame::initListeners()
// Safe impossible cases
// We can't work without these helpers!
- SAL_WARN_IF( !xDispatchProvider.is(), "fwk", "Frame::Frame(): Slowest slave for dispatch- and interception helper isn't valid. XDispatchProvider, XDispatch, XDispatchProviderInterception are not full supported!" );
- SAL_WARN_IF( !m_xDispatchHelper.is(), "fwk", "Frame::Frame(): Interception helper isn't valid. XDispatchProvider, XDispatch, XDispatchProviderInterception are not full supported!" );
- SAL_WARN_IF( !m_xFramesHelper.is(), "fwk", "Frame::Frame(): Frames helper isn't valid. XFrames, XIndexAccess and XElementAcces are not supported!" );
- SAL_WARN_IF( !m_xDropTargetListener.is(), "fwk", "Frame::Frame(): DropTarget helper isn't valid. Drag and drop without functionality!" );
+ SAL_WARN_IF( !xDispatchProvider.is(), "fwk", "Frame::Frame(): Slowest slave for dispatch- and interception helper is not valid. XDispatchProvider, XDispatch, XDispatchProviderInterception are not full supported!" );
+ SAL_WARN_IF( !m_xDispatchHelper.is(), "fwk", "Frame::Frame(): Interception helper is not valid. XDispatchProvider, XDispatch, XDispatchProviderInterception are not full supported!" );
+ SAL_WARN_IF( !m_xFramesHelper.is(), "fwk", "Frame::Frame(): Frames helper is not valid. XFrames, XIndexAccess and XElementAcces are not supported!" );
+ SAL_WARN_IF( !m_xDropTargetListener.is(), "fwk", "Frame::Frame(): DropTarget helper is not valid. Drag and drop without functionality!" );
// establish notifies for changing of "disabled commands" configuration during runtime
m_aCommandOptions.EstablisFrameCallback(this);
@@ -582,7 +582,7 @@ Frame::~Frame()
As result of this operation we return the new created component or nothing, if loading failed.
@param "sURL" , URL, which represant the content
@param "sTargetFrameName" , name of target frame or special value like "_self", "_blank" ...
- @param "nSearchFlags" , optional arguments for frame search, if target isn't a special one
+ @param "nSearchFlags" , optional arguments for frame search, if target is not a special one
@param "lArguments" , optional arguments for loading
@return A valid component reference, if loading was successfully.
A null reference otherwise.
@@ -731,7 +731,7 @@ void SAL_CALL Frame::setActiveFrame( const css::uno::Reference< css::frame::XFra
}
// If last active frame was active ...
- // but new one isn't it ...
+ // but new one is not it ...
// ... set it as active one.
if (
( eActiveState == E_ACTIVE ) &&
@@ -806,7 +806,7 @@ void SAL_CALL Frame::initialize( const css::uno::Reference< css::awt::XWindow >&
if ( m_xContainerWindow.is() )
throw css::uno::RuntimeException(
- "Frame::initialized() is called more than once, which isnt useful nor allowed.",
+ "Frame::initialized() is called more than once, which is not useful nor allowed.",
static_cast< css::frame::XFrame* >(this));
// Look for rejected calls first!
@@ -1139,7 +1139,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Frame::findFrame( const OUStr
// II.III) TASKS
// This is a special flag. It regulate search on this task tree only or allow search on
// all other ones (which are sibling trees of us) too.
- // Upper search must stop at this frame if we are the topest one and the TASK flag isn't set
+ // Upper search must stop at this frame if we are the topest one and the TASK flag is not set
// or we can ignore it if we have no valid parent.
if (
@@ -1150,7 +1150,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Frame::findFrame( const OUStr
// II.III.I) SIBLINGS
// Search on all our direct siblings - means all children of our parent.
- // Use this flag in combination with TASK. We must supress such upper search if
+ // Use this flag in combination with TASK. We must suppress such upper search if
// user has not set it and if we are a top frame.
// Attention: Don't forward this request to our parent as a findFrame() call.
// In such case we must protect us against recursive calls.
@@ -2196,7 +2196,7 @@ css::uno::Reference< css::task::XStatusIndicator > SAL_CALL Frame::createStatusI
@param "aURL" , URL for loading
@param "sTargetFrameName" , name of target frame
- @param "nSearchFlags" , additional flags to regulate search if sTargetFrameName isn't clear
+ @param "nSearchFlags" , additional flags to regulate search if sTargetFrameName is not clear
@return css::uno::Reference to dispatch handler.
@onerror A null reference is returned.
@@ -2207,7 +2207,7 @@ css::uno::Reference< css::frame::XDispatch > SAL_CALL Frame::queryDispatch( cons
{
const char UNO_PROTOCOL[] = ".uno:";
- // Don't check incoming parameter here! Our helper do it for us and it isn't a good idea to do it more than ones!
+ // Don't check incoming parameter here! Our helper do it for us and it is not a good idea to do it more than ones!
// But look for rejected calls!
TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
@@ -2242,7 +2242,7 @@ css::uno::Reference< css::frame::XDispatch > SAL_CALL Frame::queryDispatch( cons
*//*-*****************************************************************************************************/
css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL Frame::queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& lDescriptor ) throw( css::uno::RuntimeException, std::exception )
{
- // Don't check incoming parameter here! Our helper do it for us and it isn't a good idea to do it more than ones!
+ // Don't check incoming parameter here! Our helper do it for us and it is not a good idea to do it more than ones!
// But look for rejected calls!
TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
@@ -2610,7 +2610,7 @@ void SAL_CALL Frame::removeActionLock() throw( css::uno::RuntimeException, std::
{
SolarMutexGuard g;
- SAL_WARN_IF( m_nExternalLockCount<=0, "fwk", "Frame::removeActionLock(): Frame isn't locked! Possible multithreading problem detected." );
+ SAL_WARN_IF( m_nExternalLockCount<=0, "fwk", "Frame::removeActionLock(): Frame is not locked! Possible multithreading problem detected." );
--m_nExternalLockCount;
}
@@ -3097,7 +3097,7 @@ void Frame::implts_checkSuicide()
aReadLock.clear();
/* } SAFE */
// force close and deliver owner ship to source of possible throwed veto exception
- // Attention: Because this method isn't designed to throw such exception we must suppress
+ // Attention: Because this method is not designed to throw such exception we must suppress
// it for outside code!
try
{
@@ -3123,7 +3123,7 @@ void Frame::implts_checkSuicide()
void Frame::impl_setCloser( /*IN*/ const css::uno::Reference< css::frame::XFrame2 >& xFrame ,
/*IN*/ bool bState )
{
- // Note: If start module isn't installed - no closer has to be shown!
+ // Note: If start module is not installed - no closer has to be shown!
if (!SvtModuleOptions().IsModuleInstalled(SvtModuleOptions::E_SSTARTMODULE))
return;
diff --git a/framework/source/services/modulemanager.cxx b/framework/source/services/modulemanager.cxx
index 7d3716c4bb5a..7a3cee7dcc1f 100644
--- a/framework/source/services/modulemanager.cxx
+++ b/framework/source/services/modulemanager.cxx
@@ -222,7 +222,7 @@ OUString SAL_CALL ModuleManager::identify(const css::uno::Reference< css::uno::X
if (sModule.isEmpty())
throw css::frame::UnknownModuleException(
- OUString("Cant find suitable module for the given component."),
+ OUString("Can not find suitable module for the given component."),
static_cast< ::cppu::OWeakObject* >(this));
return sModule;
diff --git a/framework/source/services/pathsettings.cxx b/framework/source/services/pathsettings.cxx
index f82fc248a2a3..e248e77ba083 100644
--- a/framework/source/services/pathsettings.cxx
+++ b/framework/source/services/pathsettings.cxx
@@ -649,9 +649,9 @@ PathSettings::PathInfo PathSettings::impl_readNewFormat(const OUString& sPath)
css::beans::Property aInfo = xInfo->getAsProperty();
bool bFinalized = ((aInfo.Attributes & css::beans::PropertyAttribute::READONLY ) == css::beans::PropertyAttribute::READONLY );
- // Note: Till we support finalized / mandatory on our API more in detail we handle
- // all states simple as READONLY ! But because all really needed paths are "mandatory" by default
- // we have to handle "finalized" as the real "readonly" indicator .
+ // Note: 'till we support finalized/mandatory on our API more in detail we handle
+ // all states simple as READONLY! But because all really needed paths are "mandatory" by default
+ // we have to handle "finalized" as the real "readonly" indicator.
aPathVal.bIsReadonly = bFinalized;
}
@@ -665,8 +665,8 @@ void PathSettings::impl_storePath(const PathSettings::PathInfo& aPath)
css::uno::Reference< css::container::XNameAccess > xCfgNew = fa_getCfgNew();
css::uno::Reference< css::container::XNameAccess > xCfgOld = fa_getCfgOld();
- // try to replace path-parts with well known and uspported variables.
- // So an office can be moved easialy to another location without loosing
+ // try to replace path-parts with well known and supported variables.
+ // So an office can be moved easialy to another location without losing
// it's related paths.
PathInfo aResubstPath(aPath);
impl_subst(aResubstPath, true);
@@ -687,9 +687,9 @@ void PathSettings::impl_storePath(const PathSettings::PathInfo& aPath)
::comphelper::ConfigurationHelper::flush(xCfgNew);
- // remove the whole path from the old configuration !
+ // remove the whole path from the old configuration!
// Otherwise we can't make sure that the diff between new and old configuration
- // on loading time really represent an user setting !!!
+ // on loading time really represents a user setting!!!
// Check if the given path exists inside the old configuration.
// Because our new configuration knows more than the list of old paths ... !
@@ -846,11 +846,11 @@ css::uno::Sequence< sal_Int32 > PathSettings::impl_mapPathName2IDList(const OUSt
// Attention: The default set of IDs is fix and must follow these schema.
// Otherwhise the outside code ant work for new added properties.
- // Why ?
+ // Why?
// The outside code must fire N events for every changed property.
// And the knowing about packaging of variables of the structure PathInfo
- // follow these group IDs ! But if such ID isnt in the range of [0..IDGROUP_COUNT]
- // the outside can't determine the right group ... and cant fire the right events .-)
+ // follow these group IDs! But if such ID is not in the range of [0..IDGROUP_COUNT]
+ // the outside can't determine the right group ... and can not fire the right events .-)
css::uno::Sequence< sal_Int32 > lIDs(IDGROUP_COUNT);
lIDs[0] = IDGROUP_OLDSTYLE;
diff --git a/framework/source/services/substitutepathvars.cxx b/framework/source/services/substitutepathvars.cxx
index 3a55a2dd324a..be0b8a2bee3d 100644
--- a/framework/source/services/substitutepathvars.cxx
+++ b/framework/source/services/substitutepathvars.cxx
@@ -177,7 +177,7 @@ enum PreDefVariable
PREDEFVAR_PROGURL,
PREDEFVAR_USERURL,
PREDEFVAR_WORKDIRURL,
- // New variable of hierachy service (#i32656#)
+ // New variable of hierarchy service (#i32656#)
PREDEFVAR_BASEINSTURL,
PREDEFVAR_USERDATAURL,
PREDEFVAR_BRANDBASEURL,
@@ -1260,13 +1260,13 @@ void SubstitutePathVariables::SetPredefinedPathVariables()
m_aPreDefVars.m_FixedVar[ PREDEFVAR_INSTPATH ] = m_aPreDefVars.m_FixedVar[PREDEFVAR_BRANDBASEURL];
m_aPreDefVars.m_FixedVar[ PREDEFVAR_INSTURL ] = m_aPreDefVars.m_FixedVar[ PREDEFVAR_INSTPATH ];
m_aPreDefVars.m_FixedVar[ PREDEFVAR_INST ] = m_aPreDefVars.m_FixedVar[ PREDEFVAR_INSTPATH ];
- // New variable of hierachy service (#i32656#)
+ // New variable of hierarchy service (#i32656#)
m_aPreDefVars.m_FixedVar[ PREDEFVAR_BASEINSTURL ]= m_aPreDefVars.m_FixedVar[ PREDEFVAR_INSTPATH ];
// Set $(user), $(userpath), $(userurl)
m_aPreDefVars.m_FixedVar[ PREDEFVAR_USERURL ] = m_aPreDefVars.m_FixedVar[ PREDEFVAR_USERPATH ];
m_aPreDefVars.m_FixedVar[ PREDEFVAR_USER ] = m_aPreDefVars.m_FixedVar[ PREDEFVAR_USERPATH ];
- // New variable of hierachy service (#i32656#)
+ // New variable of hierarchy service (#i32656#)
m_aPreDefVars.m_FixedVar[ PREDEFVAR_USERDATAURL ]= m_aPreDefVars.m_FixedVar[ PREDEFVAR_USERPATH ];
// Detect the program directory
diff --git a/framework/source/uiconfiguration/uicategorydescription.cxx b/framework/source/uiconfiguration/uicategorydescription.cxx
index a2c69479a20b..f7dd8196d4a4 100644
--- a/framework/source/uiconfiguration/uicategorydescription.cxx
+++ b/framework/source/uiconfiguration/uicategorydescription.cxx
@@ -128,7 +128,7 @@ ConfigurationAccess_UICategory::ConfigurationAccess_UICategory( const OUString&
m_bConfigAccessInitialized( false ),
m_bCacheFilled( false )
{
- // Create configuration hierachical access name
+ // Create configuration hierarchical access name
m_aConfigCategoryAccess += aModuleName;
m_aConfigCategoryAccess += CONFIGURATION_CATEGORY_ELEMENT_ACCESS;
diff --git a/framework/source/jobs/job.cxx b/framework/source/jobs/job.cxx
index 28f9e79c1638..50934c96ff7b 100644
--- a/framework/source/jobs/job.cxx
+++ b/framework/source/jobs/job.cxx
@@ -333,7 +333,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
JobData::EMode eMode = m_aJobCfg.getMode();
// Create list of environment variables. This list must be part of the
// returned structure everytimes ... but some of its members are opetional!
css::uno::Sequence< css::beans::NamedValue > lEnvArgs(1);
lEnvArgs[0].Name = "EnvType";
lEnvArgs[0].Value <<= m_aJobCfg.getEnvironmentDescriptor();
@@ -411,7 +411,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
@short analyze the given job result and change the job configuration
@descr Note: Some results can be handled only, if this job has a valid configuration!
For "not configured jobs" (means pure services) they can be ignored.
- But these cases are handled by our JobData member. We can call it everytime.
+ But these cases are handled by our JobData member. We can call it every time.
It does the right things automatically. E.g. if the job has no configuration ...
it does nothing during setJobConfig()!
@@ -475,7 +475,7 @@ void Job::impl_reactForJobResult( /*IN*/ const css::uno::Any& aResult )
at the global desktop instance. That will hold us
alive and additional we get the information, if the
office wish to shutdown. If then an internal job
- is running we will have the chance to supress that
+ is running we will have the chance to suppress that
by throwing a veto exception. If our internal wrapped
job finished his work, we can release this listener
connection.
@@ -333,7 +333,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
JobData::EMode eMode = m_aJobCfg.getMode();
// Create list of environment variables. This list must be part of the
- // returned structure everytimes ... but some of its members are opetional!
+ // returned structure every time... but some of its members are opetional!
css::uno::Sequence< css::beans::NamedValue > lEnvArgs(1);
lEnvArgs[0].Name = "EnvType";
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index 9102d73e26fc..1bf2f1098b64 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -200,9 +200,9 @@ public:
/* FINAL STATES */
- /// the Auto/Emergency saved document isnt useable any longer
+ /// the Auto/Emergency saved document is not useable any longer
E_DAMAGED = 64,
- /// the Auto/Emergency saved document isnt really up-to-date (some changes can be missing)
+ /// the Auto/Emergency saved document is not really up-to-date (some changes can be missing)
E_INCOMPLETE = 128,
/// the Auto/Emergency saved document was processed successfully
E_SUCCEDED = 512
@@ -286,7 +286,7 @@ public:
sal_Int32 DocumentState;
/** Because our applications not ready for concurrent save requests at the same time,
- we have supress our own AutoSave for the moment, a document will be already saved
+ we have suppress our own AutoSave for the moment, a document will be already saved
by others.
*/
bool UsedForSaving;
@@ -317,7 +317,7 @@ public:
OUString AppModule; // e.g. com.sun.star.text.TextDocument - used to identify app module
OUString FactoryService; // the service to create a document of the module
OUString RealFilter; // real filter, which was used at loading time
- OUString DefaultFilter; // supports saving of the default format without loosing data
+ OUString DefaultFilter; // supports saving of the default format without losing data
OUString Extension; // file extension of the default filter
OUString Title; // can be used as "DisplayName" on every recovery UI!
css::uno::Sequence< OUString >
@@ -585,7 +585,7 @@ private:
@descr ... but only keys related to the AutoSave mechanism.
Means: State and Timer intervall.
- E.g. the recovery list isnt adressed here.
+ E.g. the recovery list is not addressed here.
@throw [com.sun.star.uno.RuntimeException]
if config could not be opened or readed successfully!
@@ -964,14 +964,14 @@ private:
a) An external progress is provided by our CrashSave or Recovery dialog.
b) We must create our own progress e.g. for an AutoSave
c) Sometimes our application filters dont use the progress
- provided by the MediaDescriptor. They uses the Frame everytime to create
+ provided by the MediaDescriptor. They use the Frame every time to create
it's own progress. So we implemented a HACK for these and now we set
an InterceptedProgress there for the time WE use this frame for loading/storing documents .-)
@param xNewFrame
must be set only in case WE create a new frame (e.g. for loading documents
on session restore or recovery). Then search for a frame using rInfo.Document must
- be supressed and xFrame must be preferred instead .-)
+ be suppressed and xFrame must be preferred instead .-)
@param rInfo
used e.g. to find the frame corresponding to a document.
@@ -1006,10 +1006,10 @@ private:
void st_impl_removeFile(const OUString& sURL);
/** try to remove ".lock" file from disc if office will be terminated
- not using the offical way .-)
+ not using the official way .-)
This method has to be handled "optional". So every error inside
- has to be ignored ! This method CANT FAIL ... it can forget something only .-)
+ has to be ignored ! This method CAN NOT FAIL ... it can forget something only .-)
*/
void st_impl_removeLockFile();
};
@@ -1109,7 +1109,7 @@ static const sal_Int32 GIVE_UP_RETRY = 1; // in
// enable the following defines in case you wish to simulate a full disc for debug purposes .-)
// this define throws everytime a document is stored or a configuration change
// should be flushed an exception ... so the special error handler for this scenario is triggered
// #define TRIGGER_FULL_DISC_CHECK
@@ -1121,7 +1121,7 @@ class CacheLockGuard
private:
// holds the outside calli alive, so it's shared resources
- // are valid everytimes
+ // are valid every time
css::uno::Reference< css::uno::XInterface > m_xOwner;
// mutex shared with outside calli !
@@ -1346,7 +1346,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
// This can be done immediately ... must not been done asynchronous.
if ((eNewJob & AutoRecovery::E_DISABLE_AUTORECOVERY) == AutoRecovery::E_DISABLE_AUTORECOVERY)
{
// it's important to set a flag internally, so AutoRecovery will be supressed - even if it's requested.
m_eJob |= eNewJob;
implts_stopTimer();
implts_stopListening();
@@ -1608,7 +1608,7 @@ void SAL_CALL AutoRecovery::notifyEvent(const css::document::EventObject& aEvent
implts_updateModifiedState(xDocument);
}
/* at least one document starts saving process =>
- Our application code isn't ready for multiple save requests
+ Our application code is not ready for multiple save requests
at the same time. So we have to suppress our AutoSave feature
for the moment, till this other save requests will be finished.
*/
@@ -1706,7 +1706,7 @@ void SAL_CALL AutoRecovery::changesOccurred(const css::util::ChangesEvent& aEven
// Note: This call stops the timer and starts it again.
// But it checks the different timer states internally and
// may be supress the restart!
implts_updateTimer();
}
@@ -1939,7 +1939,7 @@ void AutoRecovery::implts_specifyDefaultFilterAndExtension(AutoRecovery::TDocume
if (rInfo.AppModule.isEmpty())
{
throw css::uno::RuntimeException(
- "Cant find out the default filter and its extension, if no application module is known!",
+ "Can not find out the default filter and its extension, if no application module is known!",
static_cast< css::frame::XDispatch* >(this));
}
@@ -2000,7 +2000,7 @@ void AutoRecovery::implts_specifyAppModuleAndFactory(AutoRecovery::TDocumentInfo
{
ENSURE_OR_THROW2(
!rInfo.AppModule.isEmpty() || rInfo.Document.is(),
- "Cant find out the application module nor its factory URL, if no application module (or a suitable) document is known!",
+ "Can not find out the application module nor its factory URL, if no application module (or a suitable) document is known!",
*this );
css::uno::Reference< css::frame::XModuleManager2 > xManager = ModuleManager::create(m_xContext);
@@ -2390,7 +2390,7 @@ IMPL_LINK_NOARG(AutoRecovery, implts_timerExpired)
bool bAllowUserIdleLoop = true;
AutoRecovery::ETimerType eSuggestedTimer = implts_saveDocs(bAllowUserIdleLoop, false);
- // If timer isn't used for "short callbacks" (means polling
+ // If timer is not used for "short callbacks" (means polling
// for special states) ... reset the handle state of all
// cache items. Such handle state indicates, that a document
// was already saved during the THIS(!) AutoSave session.
@@ -2547,7 +2547,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
/* SAFE */ {
osl::MutexGuard g(cppu::WeakComponentImplHelperBase::rBHelper.rMutex);
- // create a new cache entry ... this document isn't known.
+ // create a new cache entry ... this document is not known.
++m_nIdPool;
aNew.ID = m_nIdPool;
SAL_WARN_IF(m_nIdPool<0, "fwk", "AutoRecovery::implts_registerDocument(): Overflow of ID pool detected.");
@@ -2877,8 +2877,8 @@ void AutoRecovery::implts_prepareSessionShutdown()
if implts_registerDocument() was called.
So we have to check a second time, if this property is set ....
Best place doing so is to check it immeditaly before saving
- and supressingd saving the document then.
- Of course removing the corresponding cache entry isn't an option.
+ and suppressingd saving the document then.
+ Of course removing the corresponding cache entry is not an option.
Because it would disturb iteration over the cache !
So we ignore such documents only ...
Hopefully next time they are not inserted in our cache.
@@ -3104,7 +3104,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
// for make hyperlinks working
lNewArgs[utl::MediaDescriptor::PROP_DOCUMENTBASEURL()] <<= OUString();
// try to save this document as a new temp file everytimes.
// Mark AutoSave state as "INCOMPLETE" if it failed.
// Because the last temp file is to old and does not include all changes.
Reference< XDocumentRecovery > xDocRecover(rInfo.Document, css::uno::UNO_QUERY_THROW);
@@ -3190,7 +3190,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
rInfo.DocumentState |= AutoRecovery::E_INCOMPLETE;
}
- // make sure the progress isn't referred any longer
+ // make sure the progress is not referred any longer
impl_forgetProgress(rInfo, lNewArgs, css::uno::Reference< css::frame::XFrame >());
// try to remove the old temp file.
@@ -4259,7 +4259,7 @@ void AutoRecovery::impl_establishProgress(const AutoRecovery::TDocumentInfo&
// So we use a two step mechanism:
// 1) we set the progress inside the MediaDescriptor, which will be provided to the filter
// 2) and we set a special Frame property, which overwrites the normal behaviour of Frame::createStatusIndicator .-)
// But we supress 2) in case we uses an internal progress. Because then it doesn't matter
// if our applications make it wrong. In such case the internal progress resists at the same frame
// and there is no need to forward progress activities to e.g. an outside dialog .-)
if (
@@ -1109,7 +1109,7 @@ static const sal_Int32 GIVE_UP_RETRY = 1; // in
// enable the following defines in case you wish to simulate a full disc for debug purposes .-)
-// this define throws everytime a document is stored or a configuration change
+// this define throws every time a document is stored or a configuration change
// should be flushed an exception ... so the special error handler for this scenario is triggered
// #define TRIGGER_FULL_DISC_CHECK
@@ -1346,7 +1346,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
if ((eNewJob & AutoRecovery::E_DISABLE_AUTORECOVERY) == AutoRecovery::E_DISABLE_AUTORECOVERY)
{
- // it's important to set a flag internally, so AutoRecovery will be supressed - even if it's requested.
+ // it's important to set a flag internally, so AutoRecovery will be suppressed - even if it's requested.
m_eJob |= eNewJob;
implts_stopTimer();
@@ -1706,7 +1706,7 @@ void SAL_CALL AutoRecovery::changesOccurred(const css::util::ChangesEvent& aEven
// Note: This call stops the timer and starts it again.
// But it checks the different timer states internally and
- // may be supress the restart!
+ // may be suppress the restart!
implts_updateTimer();
}
@@ -3104,7 +3104,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
// for make hyperlinks working
lNewArgs[utl::MediaDescriptor::PROP_DOCUMENTBASEURL()] <<= OUString();
- // try to save this document as a new temp file everytimes.
+ // try to save this document as a new temp file every time.
// Mark AutoSave state as "INCOMPLETE" if it failed.
// Because the last temp file is to old and does not include all changes.
@@ -4259,7 +4259,7 @@ void AutoRecovery::impl_establishProgress(const AutoRecovery::TDocumentInfo&
// 1) we set the progress inside the MediaDescriptor, which will be provided to the filter
// 2) and we set a special Frame property, which overwrites the normal behaviour of Frame::createStatusIndicator .-)
- // But we supress 2) in case we uses an internal progress. Because then it doesn't matter
+ // But we suppress 2) in case we uses an internal progress. Because then it doesn't matter
// if our applications make it wrong. In such case the internal progress resists at the same frame
// and there is no need to forward progress activities to e.g. an outside dialog .-)